@@ -2,9 +2,9 @@ use crate::debug::dump;
 use std::fmt::Debug;
 use swc_common::Mark;
 use swc_ecma_ast::*;
-use swc_ecma_transforms::fixer;
+use swc_ecma_transforms::{fixer, hygiene};
 use swc_ecma_utils::DropSpan;
-use swc_ecma_visit::{FoldWith, VisitMut, VisitMutWith};
+use swc_ecma_visit::{as_folder, FoldWith, VisitMut, VisitMutWith};
 
 /// Indicates a unit of minifaction.
 pub(crate) trait CompileUnit:
@@ -33,7 +33,19 @@ impl CompileUnit for Module {
     }
 
     fn dump(&self) -> String {
-        dump(&self.clone().fold_with(&mut fixer(None)))
+        if !cfg!(feature = "debug") {
+            return String::new();
+        }
+
+        dump(
+            &self
+                .clone()
+                .fold_with(&mut fixer(None))
+                .fold_with(&mut hygiene())
+                .fold_with(&mut as_folder(DropSpan {
+                    preserve_ctxt: false,
+                })),
+        )
     }
 
     fn apply<V>(&mut self, visitor: &mut V)
@@ -58,7 +70,19 @@ impl CompileUnit for FnExpr {
     }
 
     fn dump(&self) -> String {
-        dump(&self.clone().fold_with(&mut fixer(None)))
+        if !cfg!(feature = "debug") {
+            return String::new();
+        }
+
+        dump(
+            &self
+                .clone()
+                .fold_with(&mut fixer(None))
+                .fold_with(&mut hygiene())
+                .fold_with(&mut as_folder(DropSpan {
+                    preserve_ctxt: false,
+                })),
+        )
     }
 
     fn apply<V>(&mut self, visitor: &mut V)
